#
# spec file for package python-oslo.reports
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           python-oslo.reports
Version:        2.4.0
Release:        1.5
Summary:        OpenStack oslo.reports library
License:        Apache-2.0
Group:          Development/Languages/Python
URL:            https://docs.openstack.org/oslo.reports
Source0:        https://files.pythonhosted.org/packages/source/o/oslo.reports/oslo.reports-2.4.0.tar.gz
BuildRequires:  openstack-macros
BuildRequires:  python3-Jinja2 >= 2.10
BuildRequires:  python3-eventlet
BuildRequires:  python3-greenlet
BuildRequires:  python3-oslo.config
BuildRequires:  python3-oslo.i18n >= 3.15.3
BuildRequires:  python3-oslo.serialization >= 2.18.0
BuildRequires:  python3-oslo.utils >= 3.33.0
BuildRequires:  python3-oslotest
BuildRequires:  python3-pbr >= 2.0.0
BuildRequires:  python3-psutil >= 3.2.2
BuildRequires:  python3-stestr
BuildArch:      noarch

%description
The project oslo.reports hosts a general purpose error report generation
framework, known as the "guru meditation report".

%package -n python3-oslo.reports
Summary:        OpenStack oslo.reports library
Requires:       python3-Jinja2 >= 2.10
Requires:       python3-oslo.i18n >= 3.15.3
Requires:       python3-oslo.serialization >= 2.18.0
Requires:       python3-oslo.utils >= 3.33.0
Requires:       python3-psutil >= 3.2.2

%description -n python3-oslo.reports
The project oslo.reports hosts a general purpose error report generation
framework, known as the "guru meditation report".

%package -n python-oslo.reports-doc
Summary:        Documentation for OpenStack reports library
BuildRequires:  python3-Sphinx
BuildRequires:  python3-openstackdocstheme
BuildRequires:  python3-sphinxcontrib-apidoc

%description -n python-oslo.reports-doc
The project oslo.reports hosts a general purpose error report generation
framework, known as the "guru meditation report".
This package contains the documentation.

%prep
%autosetup -p1 -n oslo.reports-2.4.0
%py_req_cleanup

%build
%{py3_build}

# generate html docs
PBR_VERSION=%{version} %sphinx_build -b html doc/source doc/build/html
# remove the sphinx-build leftovers
rm -rf doc/build/html/.{doctrees,buildinfo}

%install
%{py3_install}

%check
python3 -m stestr.cli run

%files -n python3-oslo.reports
%license LICENSE
%doc README.rst ChangeLog
%{python3_sitelib}/oslo_reports
%{python3_sitelib}/*.egg-info

%files -n python-oslo.reports-doc
%license LICENSE
%doc doc/build/html

%changelog
* Tue Jun  7 2022 cloud-devel@suse.de
- update to version 2.4.0
  - Support integer keys of dicts in text serialization
  - Update CI to use unversioned jobs template
  - Changed minversion in tox to 3.18.0
* Tue Oct 26 2021 cloud-devel@suse.de
- update to version 2.3.0
  - Switch testing to Xena testing runtime
  - Fix hacking min version to 3.0.1
  - Remove all six usage
  - Remove lower-constraints remnants
  - Update master for stable/victoria
  - Move flake8 as a pre-commit local target.
  - Use py3 as the default runtime for tox
  - Dropping lower constraints testing
  - setup.cfg: Replace dashes with underscores
  - Add Python3 wallaby unit tests
  - Use TOX_CONSTRAINTS_FILE
  - Adding pre-commit
  - Replace concatenation with f-strings
* Fri Oct  9 2020 cloud-devel@suse.de
- update to version 2.2.0
  - Remove the unused coding style modules
  - Add Python3 victoria unit tests
  - [goal] Migrate testing to ubuntu focal
  - Bump default tox env from py37 to py38
  - Update master for stable/ussuri
  - Align contributing doc with oslo's policy
  - Fix pygments style
  - Bump bandit version
  - Switch to newer openstackdocstheme and reno versions
  - Add release notes links to doc index
  - Remove translation sections from setup.cfg
  - Add py38 package metadata
  - Stop to use the __future__ module.
* Tue May 12 2020 cloud-devel@suse.de
- update to version 2.0.1
  - Exclude tests from apidoc
  - trivial: Remove cruft from sphinx config file
  - Update master for stable/train
  - tox: Keeping going with docs
  - Use unittest.mock instead of third party mock
  - [ussuri][goal] Drop python 2.7 support and testing
  - remove outdated header
  - Switch to Ussuri jobs
  - Switch from 'collections' -> 'collections.abc'
  - tox: Add missing deps for 'releasenotes' job
  - Update the constraints url
  - Update hacking for Python3
  - tox: Trivial cleanup
* Sat Mar 14 2020 Dirk Mueller <dmueller@suse.com>
- switch to python 3.x only builds
* Wed Oct  9 2019 cloud-devel@suse.de
- update to version 1.30.0
  - Replace git.openstack.org URLs with opendev.org URLs
  - Sync Sphinx requirement
  - OpenDev Migration Patch
  - Move doc related modules to doc/requirements.txt
  - Update master for stable/stein
  - Add Python 3 Train unit tests
* Mon Apr  8 2019 cloud-devel@suse.de
- update to version 1.29.2
  - Update hacking version
  - Update mailinglist from dev to discuss
  - fix tox python3 overrides
  - Replace deprecated "auth_uri" by "www_authenticate_uri"
  - Update unit test to reflect latest oslo.config
  - Remove the remaining of the removed option
  - Trivial: Update pypi url to new url
  - Update reno for stable/rocky
  - import zuul job settings from project-config
  - Imported Translations from Zanata
  - Remove stale pip-missing-reqs and pypy tox tests
  - Clean up .gitignore references to personal tools
  - Add release notes link to README
  - Use template for lower-constraints
  - add lib-forward-testing-python3 test job
  - add python 3.6 unit test job
  - add python 3.7 unit test job
  - Switch to stestr
- remove 0001-Update-unit-test-to-reflect-latest-oslo.config.patch (merged)
* Mon Sep  3 2018 cloud-devel@suse.de
- update to version 1.28.0
  - set default python to python3
  - Update reno for stable/queens
  - Update links in README
  - fix lower constraints and uncap eventlet
  - Imported Translations from Zanata
  - Updated from global requirements
  - add lower-constraints job
  - Document workaround for AccessDenied error
- add 0001-Update-unit-test-to-reflect-latest-oslo.config.patch
* Fri Feb 23 2018 tbechtold@suse.com
- Switch to stable/queens spec template
* Tue Jan 30 2018 cloud-devel@suse.de
- update to version 1.26.0
  - Updated from global requirements
  - Add bandit to pep8 job
* Mon Jan 15 2018 cloud-devel@suse.de
- update to version 1.25.0
  - Remove -U from pip install
  - Remove SIGUSR1 handler, which was deprecated after Ocata
  - Update reno for stable/pike
  - Remove psutil 1.x compat wrapping
  - Remove setting of version/release from releasenotes
  - Imported Translations from Zanata
  - Avoid tox_install.sh for constraints support
  - Update the documentation link
  - Updated from global requirements
* Mon Aug  7 2017 cloud-devel@suse.de
- update to version 1.22.0
  - Remove references to Python 3.4
  - Remove log translations
  - rearrange content to fit the new standard layout
  - Update reno for stable/ocata
  - Remove pbr warnerrors in favor of sphinx check
  - Updated from global requirements
  - switch from oslosphinx to openstackdocstheme
  - update the doc URL according to document migration
* Mon Feb 13 2017 cloud-devel@suse.de
- update to version 1.17.0:
  - Add Constraints support
  - Fix a typo
  - Updated from global requirements
  - Show team and repo badges on README
  - Bump hacking dep
  - Changed the home-page link
  - Add reno for release notes management
* Fri Oct 14 2016 tbechtold@suse.com
- switch to stable/newton tarball in _service
* Wed Aug 31 2016 tbechtold@suse.com
- update to version 1.14.0
  * Updated from global requirements
* Wed Aug 10 2016 tbechtold@suse.com
- update to 1.13.0:
  * Updated from global requirements
  * Add Python 3.5 classifier and venv
  * Use file modification events instead of signal handler
  * Imported Translations from Zanata
  * Trivial: ignore openstack/common in flake8 exclude list
  * Remove direct dependency on babel
- Update _service and switch to upstream spec template
* Mon Apr  4 2016 tbechtold@suse.com
- update to 1.7.0:
  * Updated from global requirements
  * Update .gitreview for stable/mitaka
* Thu Mar  3 2016 tbechtold@suse.com
- update to 1.6.0:
  * Updated from global requirements
  * Updated from global requirements
  * Updated from global requirements
  * Update translation setup
  * Updated from global requirements
  * Updated from global requirements
  * Updated from global requirements
  * Updated from global requirements
  * Updated from global requirements
  * Updated from global requirements
  * Print the traceback if there was an exception in run(
  * Rename signal handler argument to 'frame'
  * Updated from global requirements
  * Updated from global requirements
  * Trival: Remove 'MANIFEST.in'
  * Drop python 2.6 support
  * Updated from global requirements
  * Remove Python 2.6 classifier
  * Updated from global requirements
  * Remove python 2.6 and cleanup tox.ini
  * Fix Transition to SIGUSR2 in oslo.reports breaks upgrade
  * Updated from global requirements
  * Updated from global requirements
  * Updated from global requirements
  * Fix a typo in process.py
  * remove extraneous coverage omit instruction
- Adjust Requires
* Wed Oct 21 2015 dmueller@suse.com
- update to 0.7.0:
  * No need for Oslo Incubator Sync
  * Fix coverage configuration and execution
  * How to use oslo.reports documentation
  * add auto-generated api documentation
  * clean up release notes in toctree
  * add auto-generated docs for config options
  * Add shields.io version/downloads links/badges into README.rst
  * Updated from global requirements
  * guru_meditation_report: Use SIGUSR2 instead of SIGUSR1
* Wed Sep  9 2015 tbechtold@suse.com
- update to 0.5.0:
  * Updated from global requirements
  * Add a configuration for the directory to generate gmr
  * Fill README from information in the wiki
  * Setup translations
- Adjust Requires
* Mon Aug  3 2015 tbechtold@suse.com
- update to 0.3.0:
  * Updated from global requirements
  * Fix mock of open(
  * Fix GMR break with new psutil versions
  * Add oslo.utils dependency
  * Add tox target to find missing requirements
- Adjust Requires
* Mon Jul  6 2015 rsalevsky@suse.com
- initial package creation
